package ru.ulstu.paper.service;

import org.springframework.stereotype.Service;
import ru.ulstu.file.model.File;
import ru.ulstu.file.service.FileService;
import ru.ulstu.paper.model.Paper;
import ru.ulstu.paper.model.PaperDto;
import ru.ulstu.paper.repository.PaperRepository;

import javax.transaction.Transactional;
import java.io.IOException;
import java.util.Arrays;
import java.util.List;

import static ru.ulstu.core.util.StreamApiUtils.convert;

@Service
public class PaperService {

    private final PaperRepository paperRepository;
    private final FileService fileService;

    public PaperService(PaperRepository paperRepository,
                        FileService fileService) {
        this.paperRepository = paperRepository;
        this.fileService = fileService;
    }

    public List<PaperDto> findAll() {
        return convert(paperRepository.findAll(), PaperDto::new);
    }

    @Transactional
    public int create(PaperDto paperDto) throws IOException {
        return paperRepository.save(copyFromDto(new Paper(), paperDto)).getId();
    }

    private Paper copyFromDto(Paper paper, PaperDto paperDto) throws IOException {
        paper.setComment(paperDto.getComment());
        paper.setCreateDate(paperDto.getCreateDate());
        paper.setLocked(paperDto.getLocked());
        paper.setStatus(paperDto.getStatus());
        paper.setTitle(paperDto.getTitle());
        paper.setUpdateDate(paperDto.getUpdateDate());
        if (paperDto.getTmpFileName() != null) {
           paper.setFile(fileService.createFileFromTmp(paperDto.getTmpFileName()));
        }
        return paper;
    }
}
